@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use List::Util qw{ max min };
 
-our $VERSION = '0.002_02';
+our $VERSION = '0.003_01';
 
 use constant ARRAY_REF	=> ref [];
 
@@ -313,15 +313,14 @@ sub set_point_state {
     sub set_rule {
 	my ( $self, $kind, $rule ) = @_;
 	$dflt{$kind}
-	    or croak "'$kind' is not a valid rule kind";
+	    or croak "'$kind' is not a valid rule name";
 	$rule ||= $dflt{$kind};
-	my $name = ucfirst $kind;
 	ARRAY_REF eq ref $rule
-	    or croak 'Breed rule must be an array reference';
+	    or croak "\u$kind rule must be an array reference";
 	$self->{$kind} = [];
 	foreach ( @{ $rule } ) {
 	    $_ =~ NON_NEGATIVE_INTEGER_RE
-		or croak "$name rule must be a reference to an array of non-negative integers";
+		or croak "\u$kind rule must be a reference to an array of non-negative integers";
 	    $self->{$kind}[$_] = 1;
 	}
 	return;
@@ -755,7 +754,8 @@ L<Game::Life|Game::Life>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Game-Life-Faster/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -763,7 +763,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2020 by Thomas R. Wyant, III
+Copyright (C) 2019-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
